@@ -37,11 +37,15 @@
 docopt <- function( doc, args=commandArgs(TRUE), name=NULL, help=TRUE, version=NULL
                   , strict=FALSE, strip_names=!strict, quoted_args=!strict
                   ){
-  # littler compatibility - map argv vector to args
-  if (exists("argv", where = .GlobalEnv, inherits = FALSE)) {
-    args = get("argv", envir = .GlobalEnv);
-  }
   
+  if (missing(args)) {
+    # littler compatibility - map argv vector to args
+    if (exists("argv", where = .GlobalEnv, inherits = FALSE)) {
+      args = get("argv", envir = .GlobalEnv);
+    } else {
+			args <- quote_spaced(args)
+		}
+  }
   args <- str_c(args, collapse=" ")
   usage <- printable_usage(doc, name)
   pot_options <- parse_doc_options(doc)
@@ -66,8 +70,8 @@ docopt <- function( doc, args=commandArgs(TRUE), name=NULL, help=TRUE, version=N
     arguments <- m$collected
     arguments <- arguments[sapply(arguments, class) %in% c("Argument", "Command")]
     dict <- list()
+    class(dict) <- c("docopt", "list")
     
-    #for(kv in c(pot_options$options, options, pattern$flat(), m$collected)){
     for(kv in c(pot_options$options, options, pot_arguments, arguments)){
       value <- kv$value
       dict[kv$name()] <- list(value)
@@ -78,7 +82,7 @@ docopt <- function( doc, args=commandArgs(TRUE), name=NULL, help=TRUE, version=N
     }
     return(dict)
   }
-  stop(paste(usage, collapse="\n  "))
+  stop(paste("\n",usage, collapse="\n  "), call. = FALSE)
 }
          
 # print help
@@ -103,22 +107,22 @@ extras <- function(help, version=NULL, options, doc){
   if (help && any(names(opts) %in% c("-h","--help"))){
     help <- str_replace_all(doc, "^\\s*|\\s*$", "")
     cat(help,"\n")
-    if (interactive()) stop() else {
+    if (interactive()) stop(call. = FALSE) else {
       quit(save="no")
     }
   }
   if (!is.null(version) && any(names(opts) %in% "--version")){
     cat(version)
-    if (interactive()) stop() else quit(save="no")
+    if (interactive()) stop(call.  = FALSE) else quit(save="no")
   }
 }
 
 printable_usage <- function(doc, name){
   usage_split <- stringr::str_split(doc, stringr::regex("(?i)usage:\\s*"))[[1]]
   if (length(usage_split) < 2){
-    stop("'usage:' (case-insensitive) not found")
+    stop("'usage:' (case-insensitive) not found", call. = FALSE)
   } else if (length(usage_split) > 2){
-    stop('More than one "usage:" (case-insensitive).')
+    stop('More than one "usage:" (case-insensitive).', call. = FALSE)
   }
   usage <- str_split(usage_split[2], "\n\\s*")[[1]]
   firstword <- str_extract(usage, "^\\w+")
@@ -139,6 +143,13 @@ formal_usage <- function(printable_usage){
   formal <- str_c(tail(pu, -1), collapse=" ")
   formal
 }
+
+quote_spaced <- function(x){
+  ifelse( str_detect(x, "\\s")
+        , shQuote(x)
+        , x
+  )
+}
 # 
 # class Dict extends Object
 # 
@@ -150,3 +161,9 @@ formal_usage <- function(printable_usage){
 #         atts.sort()
 #         '{' + (k + ': ' + @[k] for k in atts).join(',\n ') + '}'
 # 
+
+#' @export
+print.docopt <- function(x, ...) {
+    print(str(x, give.attr=FALSE))           # convenient shortcut
+    invisible(x) 
+}
